#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 temporary
version:              1.3
visibility:           public
id:                   temporary-1.3-9rcNesEzN8L9Jsn9e228tO
key:                  temporary-1.3-9rcNesEzN8L9Jsn9e228tO
license:              BSD-3-Clause
maintainer:
    Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>, Roman Cheplyaka <roma@ro-che.info>

homepage:             https://github.com/feuerbach/temporary
synopsis:             Portable temporary file and directory support
description:          Functions for creating temporary files and directories.
category:             System, Utils
abi:                  9d75f1436ec371efc7441ea991f9c5dd
exposed:              True
exposed-modules:      System.IO.Temp
import-dirs:          /usr/lib/ghc-9.6.6/site-local/temporary-1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/temporary-1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/temporary-1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-temporary
hs-libraries:         HStemporary-1.3-9rcNesEzN8L9Jsn9e228tO
depends:
    base-4.18.2.1 directory-1.3.8.5 exceptions-0.10.7
    filepath-1.4.300.1 random-1.2.1.3-EZAJJDcAdrKCzLsP4iSxFh
    transformers-0.6.1.0 unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/haskell-temporary/html/temporary.haddock
haddock-html:         /usr/share/doc/haskell-temporary/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

